Function gaiaCastGeomCollToXY

pub unsafe extern "C" fn gaiaCastGeomCollToXY(
    geom: gaiaGeomCollPtr,
) -> gaiaGeomCollPtr
Duplicates a Geometry object [casting dimensions to 2D XY]

\param geom pointer to Geometry object [origin].

\return the pointer to newly created Geometry object: NULL on failure.

\sa gaiaCloneGeomColl, gaiaCastGeomCollToXYZ, gaiaCastGeomCollToXYM, gaiaCastGeomCollToXYZM

\note the newly created object is an exact copy of the original one; except in that any elementary item will be casted to 2D [XY] dimensions.