Function gaiaCloneGeomCollPoints

pub unsafe extern "C" fn gaiaCloneGeomCollPoints(
    geom: gaiaGeomCollPtr,
) -> gaiaGeomCollPtr
Duplicates a Geometry object [Points only]

\param geom pointer to Geometry object [origin].

\return the pointer to newly created Geometry object: NULL on failure.

\sa gaiaCloneLinestring, gaiaCloneRing, gaiaClonePolygon, gaiaCloneGeomColl, gaiaCloneGeomCollLinestrings, gaiaCloneGeomCollPolygons

\note the newly created object is an exact copy of the original one; except in that only Point objects will be copied. \n Caveat: an empty Geometry could be returned.