pub unsafe extern "C" fn gaiaCopyRingCoords(
dst: gaiaRingPtr,
src: gaiaRingPtr,
)Expand description
Copies coordinates between two RING objects
\param dst destination RING [output] \param src origin RING [input]
\sa gaiaCopyRingCoordsReverse
\note both RING objects must have exactly the same number of points: if dimensions aren’t the same for both objects, then the appropriate conversion will be silently applied.