Function gaiaGeomCollCentroid

pub unsafe extern "C" fn gaiaGeomCollCentroid(
    geom: gaiaGeomCollPtr,
    x: *mut f64,
    y: *mut f64,
) -> c_int
Spatial operator: Centroid

\param geom pointer to Geometry object. \param x on completion this variable will contain the centroid X coordinate \param y on completion this variable will contain the centroid Y coordinate

\return 0 on failure: any other value on success

\sa gaiaGeomCollCentroid_r, gaiaRingCentroid

\note not reentrant and thread unsafe.

\remark \b GEOS support required.