pub unsafe extern "C" fn gaiaGeomCollLengthOrPerimeter(
geom: gaiaGeomCollPtr,
perimeter: c_int,
length: *mut f64,
) -> c_intExpand description
Measures the total Length or Perimeter for a Geometry object
\param geom pointer to Geometry object \param perimeter if TRUE only Polygons will be considered, ignoring any Linesting \n the opposite if FALSE (considering only Linestrings and ignoring any Polygon) \param length on completion this variable will contain the measured length or perimeter
\return 0 on failure: any other value on success
\sa gaiaGeomCollLengthOrPerimeter_r, gaiaGeomCollArea, gaiaMeasureLength, gaiaGeomCollLength
\note not reentrant and thread unsafe.
\remark \b GEOS support required.