pub unsafe extern "C" fn gaiaInsertInteriorRing(
p: gaiaPolygonPtr,
ring: gaiaRingPtr,
)Expand description
Inserts an already existing Ring object into a Polygon object
\param p pointer to the Polygon object \param ring pointer to the Ring object
\sa gaiaAddRingToPolygon
\note ownership of the Ring object still remains to the calling procedure (a duplicated copy of the original Ring will be inserted into the Polygon). \n the newly created Polygon will have the same dimensions as the Ring has. \n if required the Polygon’s Interior Rings count could be increased.