Function gaiaOutFullKml

pub unsafe extern "C" fn gaiaOutFullKml(
    out_buf: gaiaOutBufferPtr,
    name: *const c_char,
    desc: *const c_char,
    geom: gaiaGeomCollPtr,
    precision: c_int,
)
Encodes a Geometry object into KML notation

\param out_buf pointer to dynamically growing Text buffer \param name text string to be set as KML \e name \param desc text string to se set as KML \e description \param geom pointer to Geometry object \param precision decimal digits to be used for coordinates

\sa gaiaParseKml, gaiaOutBareKml

\note this function will export the simplest KML notation (no descriptions).