pub unsafe extern "C" fn gaiaIsNotClosedRing(
ring: gaiaRingPtr,
) -> c_intExpand description
Checks for not-closed Rings
\param ring pointer to Ring object
\return 0 if the Ring in unclosed: otherwise any other different value.
\sa gaiaIsNotClosedRing_r, gaiaIsToxic, gaiaIsNotClosedGeomColl
\note unclosed Rings cause GEOS supported functions to crash. \n SpatiaLite will always carefully check any Ring before passing it to GEOS, eventually silently inserting a further point required so to properly close the figure. \n This function allows to explicitly identify any unclosed Ring.\n not reentrant and thread unsafe.